 local log_max_level = 56
 local gem_max_level = 10

 local assets =
{
    Asset("ANIM", "anim/aip_blue_glasses.zip"),

    Asset("ATLAS", "images/aip_blue_glasses.xml"),
    Asset("IMAGE", "images/aip_blue_glasses.tex")        
}

local function onbuilt(inst, builder) 
      if not TheWorld.state.isday then
            if inst._light == nil or not inst._light:IsValid() then
                inst._light = SpawnPrefab("glasses_light") --生成光源
                inst._light.entity:SetParent(inst.entity)  --给光源设置父节点
                inst._light.Light:SetRadius(inst.gemlevel*0.35) 
            end
      end  
end

local function OnIsNight(inst, isnight)
    if not TheWorld.state.isday and (inst._light == nil or not inst._light:IsValid()) and (inst.components.inventoryitem.owner == nil or (inst.components.inventoryitem.owner and inst.components.equippable:IsEquipped())) then
        inst._light = SpawnPrefab("glasses_light") --生成光源
        inst._light.entity:SetParent(inst.entity)  --给光源设置父节点
        inst._light.Light:SetRadius(inst.gemlevel*0.35)
    end
end    

local function OnIsDay(inst)    
    if inst._light ~= nil then
        if inst._light:IsValid() then
            inst._light:Remove()    --把光源去掉
        end
        inst._light = nil
    end
end

local function onfinished(inst)
    local removed_item = inst.components.inventory:RemoveSingleItemBySlot(1)
    if removed_item then
          removed_item:Remove()
    end
end

local function CanTakeAmmo(inst, ammo, giver)
    return (ammo.prefab == "livinglog" and inst.loglevel < log_max_level) or (ammo.prefab == "opalpreciousgem" and inst.gemlevel < gem_max_level)
end

local function OnTakeAmmo(inst, data)
    local ammo = data and data.item or nil
    if not ammo then return end
end

local function OnAccept(inst, giver, item)
    local ammo = item
    if not ammo then return end

    if ammo.prefab == "livinglog" then
           print("升级")
          -- print("等级为"..inst.loglevel)
           inst.loglevel = inst.loglevel + 1
           inst.components.armor:InitCondition(100, 0.6+(inst.loglevel*0.006)) 
    end

    if ammo.prefab == "opalpreciousgem" then
          -- print("两把")
           inst.gemlevel = inst.gemlevel + 1

           if inst._light and inst._light:IsValid() then
                 inst._light.Light:SetRadius(inst.gemlevel*0.35)
           end      

           if inst.gemlevel >= gem_max_level and inst.components.waterproofer == nil then 
                   inst:AddComponent("waterproofer")
                   inst.components.waterproofer:SetEffectiveness(TUNING.WATERPROOFNESS_ABSOLUTE)

                   inst.components.equippable.walkspeedmult = TUNING.CANE_SPEED_MULT
           end  
    end

    inst.SoundEmitter:PlaySound("dontstarve/common/together/moonbase/repair", nil, 0.7) 

    --inst.Light:SetRadius(0)          
end

local function onequip(inst, owner) 
        if not TheWorld.state.isday then
               OnIsNight(inst)
        end

        owner.AnimState:OverrideSymbol("swap_hat", "aip_blue_glasses", "swap_hat")
        owner.AnimState:Show("HAT")
        owner.AnimState:Show("HAIR_HAT")
        owner.AnimState:Hide("HAIR_NOHAT")           
end 

local function onunequip(inst, owner)
        OnIsDay(inst)

        owner.AnimState:ClearOverrideSymbol("swap_hat")
        owner.AnimState:Hide("HAT")
        owner.AnimState:Hide("HAIR_HAT")
        owner.AnimState:Show("HAIR_NOHAT")
        owner.AnimState:Show("HAIR")        
end    

local function OnSave(inst, data)
        data.loglevel = inst.loglevel or 0
        data.gemlevel = inst.gemlevel or 0
end

local function OnLoad(inst, data)
       if data and data.loglevel then
              inst.loglevel = data.loglevel
              inst.components.armor:InitCondition(100, 0.6+(inst.loglevel*0.006))
       end

       if data and data.gemlevel then
              inst.gemlevel = data.gemlevel

              if inst.gemlevel >= gem_max_level and inst.components.waterproofer == nil then 
                   inst:AddComponent("waterproofer")
                   inst.components.waterproofer:SetEffectiveness(TUNING.WATERPROOFNESS_ABSOLUTE)

                   inst.components.equippable.walkspeedmult = TUNING.CANE_SPEED_MULT
           end 
              --inst.components.armor:InitCondition(100, inst.loglevel*0.05)
       end                     
end

local function fn()
    local inst = CreateEntity()

    inst.entity:AddTransform()
    inst.entity:AddAnimState()
    inst.entity:AddSoundEmitter()
    inst.entity:AddNetwork()

    MakeInventoryPhysics(inst)

    inst:AddTag("hat")
    inst:AddTag("glasses")
    inst:AddTag("hide_percentage")

    inst:AddTag("goggles")    

    inst.AnimState:SetBank("aip_blue_glasses")
    inst.AnimState:SetBuild("aip_blue_glasses")
    inst.AnimState:PlayAnimation("anim")

  --  inst:AddTag("yuki_armor")  --这个标签能让护甲耐久比例不显示出来
    MakeInventoryFloatable(inst, "med", nil, 0.6)

    if not TheWorld.ismastersim then
        return inst
    end

    inst.entity:SetPristine()

    inst.loglevel = 0
    inst.gemlevel = 0
   
    inst:AddComponent("inventoryitem")
    inst.components.inventoryitem.imagename = "aip_blue_glasses"
    inst.components.inventoryitem.atlasname = "images/aip_blue_glasses.xml"

    inst:AddComponent("inspectable") 

    inst:AddComponent("equippable")
    --inst.components.equippable.restrictedtag = "Aegir"       
    inst.components.equippable:SetOnEquip(onequip)
    inst.components.equippable:SetOnUnequip(onunequip)
    inst.components.equippable.equipslot = EQUIPSLOTS.HEAD
    inst.components.equippable.dapperness = 0.11

    inst:AddComponent("trader")
    inst.components.trader.deleteitemonaccept = true
    inst.components.trader:SetAcceptTest(CanTakeAmmo)
    inst.components.trader.onaccept = OnAccept
    inst.components.trader.enabled = true

    inst:AddComponent("insulator")											--保温隔热
    inst.components.insulator:SetSummer()
    inst.components.insulator:SetWinter() 
    inst.components.insulator:SetInsulation(20)     

    inst:AddComponent("armor")
    inst.components.armor:InitCondition(2000, 0.6)    --60%防护系数
    inst.components.armor.indestructible = true     --无敌的护甲


    inst:DoTaskInTime(0, function(inst)
          if not TheWorld.state.isday then
                if inst._light == nil or not inst._light:IsValid() then
                        inst._light = SpawnPrefab("glasses_light") --生成光源
                        inst._light.entity:SetParent(inst.entity)  --给光源设置父节点
                        inst._light.Light:SetRadius(inst.gemlevel*0.2)
                end
         end                           
    end)

    inst:WatchWorldState("iscaveday", OnIsDay)
    inst:WatchWorldState("iscavedusk", OnIsNight)
    inst:WatchWorldState("iscavenight", OnIsNight)

    inst:WatchWorldState("isdusk", OnIsNight)
    inst:WatchWorldState("isday", OnIsDay)

    inst.OnSave = OnSave
    inst.OnPreLoad = OnLoad

    return inst
end

local function light_fn()   --设置苔衣发卡的光源
    local inst = CreateEntity()

    inst.entity:AddTransform()
    inst.entity:AddLight()
    inst.entity:AddNetwork()

    inst:AddTag("FX")

    inst.Light:SetFalloff(0.55)  --衰减
    inst.Light:SetIntensity(.7) --亮度
    inst.Light:SetRadius(0)     --半径
    inst.Light:SetColour(237/255, 237/255, 209/255) --颜色，和灯泡花一样
    inst.Light:Enable(true) 

    inst.entity:SetPristine()

    if not TheWorld.ismastersim then
        return inst
    end

    inst.persists = false

    return inst
end 

return Prefab("glasses", fn, assets),
       Prefab("glasses_light", light_fn)